==> qgvdial_0.3.1435.orig.tar.gz: qgvdial/qt-not-qml/InboxEntryDialog.cpp <==
/*
qgvdial is a cross platform Google Voice Dialer
Copyright (C) 2009-2013  Yuvraaj Kelkar

This library is free software; you can redistribute it and/or
modify it under the terms of the GNU Lesser General Public
License as published by the Free Software Foundation; either
version 2.1 of the License, or (at your option) any later version.

This library is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
Lesser General Public License for more details.

You should have received a copy of the GNU Lesser General Public
License along with this library; if not, write to the Free Software
Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA

Contact: yuvraaj@gmail.com
*/

#include "InboxEntryDialog.h"
#include "ui_InboxEntryDialog.h"
#include "InboxModel.h"

#define PIXMAP_SCALED_W 85
#define PIXMAP_SCALED_H 85

InboxEntryDialog::InboxEntryDialog(QWidget *parent)
: QDialog(parent)
, ui(new Ui::InboxEntryDialog)
{
    ui->setupUi(this);
}//InboxEntryDialog::InboxEntryDialog

InboxEntryDialog::~InboxEntryDialog()
{
    delete ui;
}//InboxEntryDialog::~InboxEntryDialog

void
InboxEntryDialog::fill(const GVInboxEntry &event)
{
    ui->lblNumber->setText (event.strPhoneNumber);
    ui->lblTime->setText (InboxModel::dateToString (event.startTime, false));
    ui->lblName->setText (event.strDisplayNumber);
    ui->lblNotes->setText (event.strNote);
}//InboxEntryDialog::fillAndExec

void
InboxEntryDialog::fill(const ContactInfo &cinfo)
{
    ui->lblName->setText (cinfo.strTitle);

    QString localPath = UNKNOWN_CONTACT_QRC_PATH;
    if (!cinfo.strPhotoPath.isEmpty ()) {
        localPath = cinfo.strPhotoPath;
    }

    QPixmap pixmap(localPath);
    ui->lblImage->setPixmap (pixmap.scaled(PIXMAP_SCALED_W, PIXMAP_SCALED_H,
                                           Qt::KeepAspectRatio));
}//InboxEntryDialog::fillAndExec

==> qgvdial_0.3.1467.orig.tar.gz: qgvdial/qt-not-qml/InboxEntryDialog.cpp <==
/*
qgvdial is a cross platform Google Voice Dialer
Copyright (C) 2009-2013  Yuvraaj Kelkar

This library is free software; you can redistribute it and/or
modify it under the terms of the GNU Lesser General Public
License as published by the Free Software Foundation; either
version 2.1 of the License, or (at your option) any later version.

This library is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
Lesser General Public License for more details.

You should have received a copy of the GNU Lesser General Public
License along with this library; if not, write to the Free Software
Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA

Contact: yuvraaj@gmail.com
*/

#include "InboxEntryDialog.h"
#include "ui_InboxEntryDialog.h"
#include "InboxModel.h"

#define PIXMAP_SCALED_W 85
#define PIXMAP_SCALED_H 85

InboxEntryDialog::InboxEntryDialog(QWidget *parent)
: QDialog(parent)
, ui(new Ui::InboxEntryDialog)
, m_numberDoubleClicked(false)
, m_contactDoubleClicked(false)
{
    ui->setupUi(this);

    connect(ui->lblNumber, SIGNAL(doubleClicked()),
            this, SLOT(onNumberDoubleClicked()));
    connect(ui->lblTime, SIGNAL(doubleClicked()),
            this, SLOT(onNumberDoubleClicked()));

    connect(ui->lblImage, SIGNAL(doubleClicked()),
            this, SLOT(onContactDoubleClicked()));
    connect(ui->lblName, SIGNAL(doubleClicked()),
            this, SLOT(onContactDoubleClicked()));
}//InboxEntryDialog::InboxEntryDialog

InboxEntryDialog::~InboxEntryDialog()
{
    delete ui;
}//InboxEntryDialog::~InboxEntryDialog

void
InboxEntryDialog::fill(const GVInboxEntry &event)
{
    ui->lblNumber->setText (event.strPhoneNumber);
    ui->lblTime->setText (InboxModel::dateToString (event.startTime, false));
    ui->lblName->setText (event.strDisplayNumber);
    ui->lblNotes->setText (event.strNote);
}//InboxEntryDialog::fill

void
InboxEntryDialog::fill(const ContactInfo &cinfo)
{
    if (!cinfo.strTitle.isEmpty ()) {
        ui->lblName->setText (cinfo.strTitle);
    }

    QString localPath = UNKNOWN_CONTACT_QRC_PATH;
    if (!cinfo.strPhotoPath.isEmpty ()) {
        localPath = cinfo.strPhotoPath;
    }

    QPixmap pixmap(localPath);
    ui->lblImage->setPixmap (pixmap.scaled(PIXMAP_SCALED_W, PIXMAP_SCALED_H,
                                           Qt::KeepAspectRatio,
                                           Qt::SmoothTransformation));
}//InboxEntryDialog::fill

void
InboxEntryDialog::onNumberDoubleClicked()
{
    m_numberDoubleClicked = true;
    this->accept ();
}//InboxEntryDialog::onNumberDoubleClicked

void
InboxEntryDialog::onContactDoubleClicked()
{
    m_contactDoubleClicked = true;
    this->accept ();
}//InboxEntryDialog::onContactDoubleClicked
